==> ejc-probid-impl-3.0.0-20220715.082857-6-sources.jar: com/ejianc/business/review/bean/ReviewFundEntity.java <==
package com.ejianc.business.review.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 投标文件评审-资金情况实体
 *
 * @author generator
 */
@TableName("ejc_probid_bid_file_review_sub_fund")
public class ReviewFundEntity extends BaseEntity {
	private static final long serialVersionUID = -610273088932843656L;

	@TableField(value = "source_bid_record_sub_fund_id")
	private Long sourceBidRecordSubFundId; // 工程投标备案-资金情况id
	@TableField(value = "source_bid_record_id")
	private Long sourceBidRecordId; // 工程投标备案id
	@TableField(value = "source_capital_id")
	private Long sourceCapitalId; // 资金来源id
	@TableField(value = "source_capital_code")
	private String sourceCapitalCode; // 资金来源编码
	@TableField(value = "source_capital_name")
	private String sourceCapitalName; // 资金来源名称
	@TableField(value = "scale")
	private BigDecimal scale; // 比例
	@TableField(value = "bid_file_review_id")
	private Long bidFileReviewId; // 投标文件评审id


	public Long getSourceBidRecordSubFundId() {
		return sourceBidRecordSubFundId;
	}

	public void setSourceBidRecordSubFundId(Long sourceBidRecordSubFundId) {
		this.sourceBidRecordSubFundId = sourceBidRecordSubFundId;
	}

	public Long getSourceBidRecordId() {
		return sourceBidRecordId;
	}

	public void setSourceBidRecordId(Long sourceBidRecordId) {
		this.sourceBidRecordId = sourceBidRecordId;
	}

	public Long getSourceCapitalId() {
		return sourceCapitalId;
	}

	public void setSourceCapitalId(Long sourceCapitalId) {
		this.sourceCapitalId = sourceCapitalId;
	}

	public String getSourceCapitalCode() {
		return sourceCapitalCode;
	}

	public void setSourceCapitalCode(String sourceCapitalCode) {
		this.sourceCapitalCode = sourceCapitalCode;
	}

	public String getSourceCapitalName() {
		return sourceCapitalName;
	}

	public void setSourceCapitalName(String sourceCapitalName) {
		this.sourceCapitalName = sourceCapitalName;
	}

	public BigDecimal getScale() {
		return scale;
	}

	public void setScale(BigDecimal scale) {
		this.scale = scale;
	}

	public Long getBidFileReviewId() {
		return bidFileReviewId;
	}

	public void setBidFileReviewId(Long bidFileReviewId) {
		this.bidFileReviewId = bidFileReviewId;
	}

}

==> ejc-probid-impl-3.0.0-20221219.112734-85-sources.jar: com/ejianc/business/review/bean/ReviewFundEntity.java <==
package com.ejianc.business.review.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 投标文件评审-资金情况实体
 *
 * @author generator
 */
@TableName("ejc_probid_bid_file_review_sub_fund")
public class ReviewFundEntity extends BaseEntity {
	private static final long serialVersionUID = 7496506325710274479L;

	@TableField(value = "source_bid_record_sub_fund_id")
	private Long sourceBidRecordSubFundId; // 工程投标备案-资金情况id
	@TableField(value = "source_bid_record_pid")
	private Long sourceBidRecordPid; // 工程投标备案id
	@TableField(value = "source_capital_id")
	private Long sourceCapitalId; // 资金来源id
	@TableField(value = "source_capital_code")
	private String sourceCapitalCode; // 资金来源编码
	@TableField(value = "source_capital_name")
	private String sourceCapitalName; // 资金来源名称
	@TableField(value = "scale")
	private BigDecimal scale; // 比例
	@TableField(value = "bid_file_review_id")
	private Long bidFileReviewId; // 投标文件评审id


	public Long getSourceBidRecordSubFundId() {
		return sourceBidRecordSubFundId;
	}

	public void setSourceBidRecordSubFundId(Long sourceBidRecordSubFundId) {
		this.sourceBidRecordSubFundId = sourceBidRecordSubFundId;
	}

	public Long getSourceBidRecordPid() {
		return sourceBidRecordPid;
	}

	public void setSourceBidRecordPid(Long sourceBidRecordPid) {
		this.sourceBidRecordPid = sourceBidRecordPid;
	}

	public Long getSourceCapitalId() {
		return sourceCapitalId;
	}

	public void setSourceCapitalId(Long sourceCapitalId) {
		this.sourceCapitalId = sourceCapitalId;
	}

	public String getSourceCapitalCode() {
		return sourceCapitalCode;
	}

	public void setSourceCapitalCode(String sourceCapitalCode) {
		this.sourceCapitalCode = sourceCapitalCode;
	}

	public String getSourceCapitalName() {
		return sourceCapitalName;
	}

	public void setSourceCapitalName(String sourceCapitalName) {
		this.sourceCapitalName = sourceCapitalName;
	}

	public BigDecimal getScale() {
		return scale;
	}

	public void setScale(BigDecimal scale) {
		this.scale = scale;
	}

	public Long getBidFileReviewId() {
		return bidFileReviewId;
	}

	public void setBidFileReviewId(Long bidFileReviewId) {
		this.bidFileReviewId = bidFileReviewId;
	}

}
